import os
import subprocess
import tempfile

from hey.consts import DEFAULT_EDITOR


def open_tmp_editor() -> str:
    """opens the default editor (`$EDITOR`)

    Returns:
        str: input string
    """

    with tempfile.NamedTemporaryFile(mode="w+", delete=False) as temp_file:
        temp_file_path = temp_file.name

    subprocess.run([DEFAULT_EDITOR, temp_file_path])

    with open(temp_file_path, "r") as file:
        data = file.read()

    os.unlink(temp_file_path)
    return data



import os
import platform

from platformdirs import user_config_path

# App name
APP_NAME = "Hey"

if platform.system().lower() == "windows":
    DEFAULT_EDITOR = os.environ.get("EDITOR", "notepad")
else:
    DEFAULT_EDITOR = os.environ.get("EDITOR", "vim")

# basic configuration setup
BASE_CONFIG = {
    "service": "https://llm.mdb.ai",
    "model": "gpt-3.5-turbo",
    "prompt": "Answer in a helpful way.",
    "code_block_theme": "github-light",
    "loading_text": "Thinking..",
    "loading_spinner": "dots",
    "never_style": False,
}

APP_CONFIG_DIR = user_config_path(APP_NAME)
CONFIG_FILE_PATH = APP_CONFIG_DIR / "config.json"



import os
import subprocess

import typer
from rich.prompt import Confirm

from hey import console
from hey.configs.utils import app_dir_exists, config_exists, init_config
from hey.consts import APP_CONFIG_DIR, CONFIG_FILE_PATH, DEFAULT_EDITOR

app = typer.Typer(help="Configuration management.")


@app.command()
def create():
    """Create a base config file."""
    if not config_exists():
        os.makedirs(APP_CONFIG_DIR)
        init_config()
    else:
        if Confirm.ask(
            "You already have a configuration file. Would you like to rewrite it?!"
        ):
            init_config()


@app.command()
def edit():
    """View and modify the config file."""
    if not app_dir_exists() or not config_exists():
        console.print("You don't have any config file. Try `hey config create` first.")
    else:
        subprocess.run([DEFAULT_EDITOR, CONFIG_FILE_PATH])



import json
import os
from hey.consts import CONFIG_FILE_PATH, BASE_CONFIG, APP_CONFIG_DIR
from hey import console


def read_configs() -> dict:
    """returns the user-defined config or the base config

    Returns:
        dict: config params
    """

    if os.path.exists(CONFIG_FILE_PATH):
        try:
            with open(CONFIG_FILE_PATH, "r") as file:
                return json.loads(file.read())
        except json.JSONDecodeError as e:
            error_message = (
                f"Your config file is [red bold]broken[/red bold]. "
                f"Try `hey config edit` or `hey config init`. {e}"
            )
            console.print(error_message)
            console.print("Using the [green bold]default settings[/green bold].")

    return BASE_CONFIG


def init_config():
    with open(CONFIG_FILE_PATH, "w+") as conf_file:
        conf_file.write(json.dumps(BASE_CONFIG, indent=4))


def app_dir_exists() -> bool:
    return os.path.exists(APP_CONFIG_DIR)


def config_exists() -> bool:
    return os.path.exists(CONFIG_FILE_PATH)
